The HTTP API Documentation extension - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# The HTTP API Documentation extension

The `http-api-doc` extension renders interactive and user-friendly HTTP API documentation using ReDoc.

Important

This extension requires npm.

Enable this extension in your project’s configuration file as follows:

YAML

    extensions:
      http-api-doc: {}

JSON

    {
      "extensions": {
        "http-api-doc": {}
      }
    }

## Configuration

This extension is not configurable.